@@ -10,10 +10,23 @@
 ##' times. Users should consider the examples for use of these
 ##' formats.
 ##'
+##' The function can either deal with combined date-time formats
+##' e.g. 10/12/1999 23:00 or with two separate columns that deal with
+##' date and time. Often there is a column for the date and another
+##' for hour. For the latter, the option \code{time.format = "\%H"}
+##' should be supplied. Note that R considers hours 0 to 23. However,
+##' if hours 1 to 24 are detected \code{import} will correct the hours
+##' accordingly.
+##'
 ##' \code{import} will also ensure wind speed and wind direction are
 ##' correctly labelled (i.e. "ws", "wd") if \code{ws} or \code{wd} are
 ##' given.
 ##'
+##' Note that it is assumed that the input data are in GMT (UTC)
+##' format and in particular there is no consideration of daylight
+##' saving time i.e. where in the input data set an hour is missing in
+##' spring and duplicated in autumn.
+##'
 ##' @param file The name of the file to be imported. Default, \code{file =
 ##'   file.choose()}, opens browser. Alternatively, the use of
 ##'   \code{read.table} (in \code{utils}) also allows this to be a character
@@ -42,14 +55,6 @@
 ##' time format must be supplied. Common examples include \dQuote{\%H:\%M}
 ##' (like 07:00) or an integer giving the hour, in which case the
 ##' format is \dQuote{\%H}. Again, see examples below.
-##' @param tz.in The time zone of the data being read. Most of the
-##' time this field can be ignored. However, one situation where it is
-##' useful to supply \code{tz.in} is if the original data considered
-##' daylight saving time i.e. there is an hour missing in spring and
-##' duplicated in autumn. An example for UK data would be \code{tz.in
-##' = "Europe/London"}.
-##' @param tz.out The time zone of the output to be used by
-##' \code{openair} functions.
 ##' @param na.strings Strings of any terms that are to be interpreted
 ##' as missing (\code{NA}). For example, this might be \dQuote{-999}, or
 ##' \dQuote{n/a} and can be of several items.
@@ -65,6 +70,7 @@
 ##' R). In which case \code{correct.time = -3600} will correct the
 ##' hour.
 ##' @param ... Other arguments passed to \code{read.table}.
+##'
 ##' @return A data frame formatted for openair use.
 ##' @author David Carslaw
 ##' @export
@@ -92,8 +98,7 @@
 ##'
 import <- function (file = file.choose(), file.type = "csv", sep = ",", header.at = 1,
                     data.at = 2,  date = "date", date.format = "%d/%m/%Y %H:%M",
-                    time = NULL,  time.format = NULL,
-                    tz.in = "GMT", tz.out = "GMT", na.strings = c("", "NA"),
+                    time = NULL,  time.format = NULL, na.strings = c("", "NA"),
                     quote = "\"", ws = NULL, wd = NULL,
                     correct.time = NULL, ...)
 {
@@ -140,17 +145,23 @@ import <- function (file = file.choose(), file.type = "csv", sep = ",", header.a
     ## set date format - if no time column use date format directly
     if (is.null(time)) {
 
-        thedata$date <- as.POSIXct(strptime(thedata$date, format = date.format, tz = tz.in))
+        thedata$date <- as.POSIXct(strptime(thedata$date, format = date.format, tz = "GMT"), tz = "GMT")
 
         ## if all dates are NA, there is a problem...
         if (all(is.na(thedata$date))) stop ("Date conversion problems, check that date.format is correct")
 
     } else {
 
+        ## correct hour if 1 to 24
+        if (time.format == "%H") {
+            if (min(thedata[, time]) == 1 & max(thedata[, time] == 24)) {
+                thedata[, time] <- thedata[, time] - 1
+            }
+        }
         ## time is in a separate column
         thedata$date <- as.POSIXct(strptime(paste(thedata$date, thedata[, time]),
                                             format = paste(date.format, time.format),
-                                            tz = tz.in))
+                                            tz = "GMT"), tz = "GMT")
 
         ## if all dates are NA, there is a problem...
         if (all(is.na(thedata$date))) stop ("Date conversion problems, check that date.format and/or time.format is correct")
@@ -158,7 +169,7 @@ import <- function (file = file.choose(), file.type = "csv", sep = ",", header.a
 
     if (!is.null(correct.time)) thedata$date <- thedata$date + correct.time
 
-    attr(thedata$date, "tzone") <- tz.out
+    attr(thedata$date, "tzone") <- "GMT"
 
     ## deal with missing dates
     ids <- which(is.na(thedata$date))
